ProvideHover

Function ProvideHover 

async fn ProvideHover(_uri: Url, _position: Struct) -> Result<Struct, String>
Internal implementation to get hover from a provider.

This would typically invoke the language feature provider registry to find an appropriate provider for the document.